@@ -14,6 +14,8 @@ use PostScript::File 1.05;      # Need cp1252 support
 my $ps = PostScript::File->new(
   paper    => 'letter',
   reencode => 'cp1252', # Best available Unicode support (still not much)
+  auto_hyphen => 0,     # We don't want any hyphen translation
+  need_fonts  => ['Helvetica'],
   left     => 72,
   top      => 72,
 );
